==> orchestra-api-4.1.0-sources.jar: org/ow2/orchestra/facade/def/ScopeActivityDefinition.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def;

import java.util.List;

import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

/**
 * @author Alfonso Fuca, S. Ali Tokmen
 */
public interface ScopeActivityDefinition extends BpelActivityWithSingleChildDefinition {

  /**
   * @return the value of ExitOnStandardFault attribute
   */
  boolean getExitOnStandardFault();

  /**
   * @return the set of variables of the scope
   */
  List<VariableDefinition> getVariables();

  /**
   * @return the set of correlations of the scope
   */
  List<CorrelationSetDefinition> getCorrelationSets();

  /**
   * @return the set of partner links of the scope
   */
  List<PartnerLinkDefinition> getPartnerLinks();

  /**
   * @return the set of partner links of the scope
   */
  List<String> getMessageExchanges();

  /**
   * @return the list of fault handlers of the scope
   */
  List<ActivityDefinitionUUID> getFaultHandlerUUIDs();

  /**
   * @return the termination handler of the scope
   */
  ActivityDefinitionUUID getTerminationHandlerDefinitionUUID();

  /**
   * @return the compensation handler of the scope
   */
  ActivityDefinitionUUID getCompensationHandlerDefinitionUUID();

}

==> orchestra-api-4.5.0-sources.jar: org/ow2/orchestra/facade/def/ScopeActivityDefinition.java <==
/**
 * Copyright (C) 2009 Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/

package org.ow2.orchestra.facade.def;

import java.util.List;

import org.ow2.orchestra.facade.uuid.ActivityDefinitionUUID;

/**
 * @author Alfonso Fuca, S. Ali Tokmen
 */
public interface ScopeActivityDefinition extends BpelActivityWithSingleChildDefinition {

  /**
   * @return the value of ExitOnStandardFault attribute
   */
  boolean getExitOnStandardFault();

  /**
   * @return the set of variables of the scope
   */
  List<VariableDefinition> getVariables();

  /**
   * @return the set of correlations of the scope
   */
  List<CorrelationSetDefinition> getCorrelationSets();

  /**
   * @return the set of partner links of the scope
   */
  List<PartnerLinkDefinition> getPartnerLinks();

  /**
   * @return the set of partner links of the scope
   */
  List<String> getMessageExchanges();

  /**
   * @return the list of fault handlers of the scope
   */
  List<ActivityDefinitionUUID> getFaultHandlerUUIDs();

  /**
   * @return the termination handler of the scope
   */
  ActivityDefinitionUUID getTerminationHandlerDefinitionUUID();

  /**
   * @return the compensation handler of the scope
   */
  ActivityDefinitionUUID getCompensationHandlerDefinitionUUID();

  /**
   * @return the list of event handlers of the scope
   */
  List< ? extends OnEventDefinition> getOnEventEventHandlers();
  List< ? extends OnAlarmDefinition> getOnAlarmEventHandlers();

}
